gramex.pptgen2 package
======================

Submodules
----------

gramex.pptgen2.commands module
------------------------------

.. automodule:: gramex.pptgen2.commands
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gramex.pptgen2
   :members:
   :undoc-members:
   :show-inheritance:
